<?php

App::uses('EvTeamAppModel', 'EvTeam.Model');

/**
 * Business rules for Pages
 */
class TeamMember extends EvTeamAppModel {

	public $displayField = 'name';

	public $actsAs = array(
		'EvTemplates.Template' => array(
			'formInject' => true,
			'restrictTo' => 'Product'
		),
		'Routable.Routable' => array(
			'alias' => 'our-team/:displayField',
			'actual' => ':plugin/:controller/view/:primaryKey'
		),
		'MetaData.Meta'
	);

	public $validate = array(
		'name' => array(
			'required' => array(
				'rule' => 'notBlank',
				'message' => 'cannot be blank'
			)
		),
	);

	public $imageSlots = array(
		'main' => array(
			'slots' => 1,
			'fields' => array()
		),
	);

	public $hasAndBelongsToMany = array(
		'Department' => array(
			'className' => 'EvTeam.Department',
			'joinTable' => 'ev_team_departments_team_members'
		)
	);

	/**
	 * Method to get TeamMembers within a department.
	 * @param   $departmentId 	Pass this is in to get the team for the
	 *                          current department only.
	 * @return   array
	 */
	public function getTeam($departmentId = null) {
		$alias = $this->alias;

		$team = $this->find('all',
			[
				'conditions' => [
					"$alias.is_active" => 1,
					'DepartmentTeamMember.department_id' => $departmentId
				],
				'joins' => [
					[
						'table' => 'ev_team_departments_team_members',
						'alias' => 'DepartmentTeamMember',
						'type' => 'INNER',
						'conditions' => [
							"DepartmentTeamMember.team_member_id = $alias.id"
						]
					]
				],
				'contain' => [
					'Image'
				],
				'order' => array("$alias.sequence ASC", "$alias.name ASC"),
			]
		);
		return $team;
	}

	/**
	 * Method to return any featured teamMembers in a random order. Not used in the plugin,
	 * but useful if you need it for your own project. Just call TeamMember->getFeatured();
	 * @return   array
	 */
	public function getFeatured() {
		return $this->find('all', array(
			'conditions' => array(
				"$alias.is_featured" => 1,
				"$alias.is_active" => 1,
			),
			'contain' => 'Image',
			'order' => 'RAND()'
		));
	}

}
